@@ -76,6 +76,8 @@ class ThreadSafeEnvironment(object):
             self.sender = self.parameters[0]
             self.text = self.parameters[1]
             self.private = self.sender == self.config["nick"]
+            if self.private:
+                self.sender = self.nick
             if saxo.address:
                 # TODO: Why was this 498 for duxlot?
                 self.limit = 493 - len(self.sender + saxo.address)
@@ -157,7 +159,7 @@ class Saxo(object):
         self.environment_cache["SAXO_BOT"] = opt["client"]["nick"]
         self.environment_cache["SAXO_BASE"] = base
         self.environment_cache["SAXO_COMMANDS"] = \
-            os.path.join(self.base, "commands")
+            os.path.join(base, "commands")
 
         self.config_cache = {}
         client_options = {
@@ -293,6 +295,20 @@ class Saxo(object):
                 # TODO: Close the socket?
                 ...
 
+    def instruction_join(self, channel):
+        # NOTE: .visit can still be followed by .join
+        # The JOIN will just fail on the server
+
+        channels = self.opt["client"]["channels"].split(" ")
+        if channel in channels:
+            # TODO: .visit it back?
+            return
+        channels.append(channel)
+        channels = " ".join(channels)
+
+        self.update_config("client", "channels", channels)
+        self.send("JOIN", channel)
+
     def instruction_link(self, channel, link):
         self.links[channel] = link
 
@@ -302,6 +318,20 @@ class Saxo(object):
     def instruction_msg(self, destination, text):
         self.send("PRIVMSG", destination, text)
 
+    def instruction_part(self, channel):
+        # NOTE: .leave can still be followed by .part
+        # The PART will just fail on the server
+
+        channels = self.opt["client"]["channels"].split(" ")
+        if channel not in channels:
+            # TODO: .leave it anyway?
+            return
+        channels.remove(channel)
+        channels = " ".join(channels)
+
+        self.update_config("client", "channels", channels)
+        self.send("PART", channel)
+
     def instruction_ping(self):
         self.send("PING", self.opt["client"]["nick"])
 
@@ -310,6 +340,9 @@ class Saxo(object):
         self.discotimer = threading.Timer(30, reconnect)
         self.discotimer.start()
 
+    def instruction_prefix(self, pfx):
+        self.update_config("client", "prefix", pfx)
+
     def instruction_propagate(self, kind="both"):
         ...
 
@@ -317,7 +350,7 @@ class Saxo(object):
         # Never call this from a thread, otherwise this can give an OSError
         self.send("QUIT")
         self.disconnect()
-        sys.exit()
+        # sys.exit()
         # TODO: Sometimes sys.exit doesn't work, not sure why
         os._exit(0)
 
@@ -367,7 +400,11 @@ class Saxo(object):
                 else:
                     cmd, arg = privmsg, ""
 
-                self.command(prefix, parameters[0], cmd, arg)
+                sender = parameters[0]
+                if sender == self.opt["client"]["nick"]:
+                    sender = prefix[0]
+
+                self.command(prefix, sender, cmd, arg)
 
         elif command == "PONG":
             if self.discotimer is not None:
@@ -382,24 +419,21 @@ class Saxo(object):
         def safe(function, irc):
             try: function(irc)
             except Exception as err:
-                debug(err)
+                debug("Thread error:", function.__name__, err)
 
-        # TODO: Remove duplication below
-        if self.first is True:
-            if ":1st" in self.events:
-                for function in self.events[":1st"]:
+        def run(name, safe, irc):
+            if name in self.events:
+                for function in self.events[name]:
                     if not function.saxo_synchronous:
                         common.thread(safe, function, irc)
                     else:
                         safe(function, irc)
-            self.first = False
 
-        if command in self.events:
-            for function in self.events[command]:
-                if not function.saxo_synchronous:
-                    common.thread(safe, function, irc)
-                else:
-                    safe(function, irc)
+        if self.first is True:
+            run(":1st", safe, irc)
+            self.first = False
+        run(command, safe, irc)
+        run("*", safe, irc)
 
     def instruction_schedule(self, unixtime, command, args):
         command = command.encode("ascii")
@@ -435,10 +469,16 @@ class Saxo(object):
                     outs = "Sorry, .%s took too long" % cmd
                 else:
                     outs = outs.decode("utf-8", "replace")
-                if not outs:
-                    outs = "Sorry, .%s did not respond" % cmd
+                    if "\n" in outs:
+                        outs = outs.splitlines()[0]
 
-            self.send("PRIVMSG", sender, outs)
+                code = proc.returncode or 0
+                # Otherwise: TypeError: unorderable types: NoneType() > int()
+                if (code > 0) and (not outs):
+                    outs = "Sorry, .%s responded with an error" % cmd
+
+            if outs:
+                self.send("PRIVMSG", sender, outs)
 
         if os.path.isfile(path):
             env = self.environment_cache.copy()
@@ -448,6 +488,17 @@ class Saxo(object):
                 env["SAXO_URL"] = self.links[sender]
             common.thread(process, env, path, arg)
 
+    def update_config(self, section, option, value):
+        self.opt[section][option] = value
+        config = os.path.join(self.base, "config")
+        with open(config, "w", encoding="utf-8") as f:
+            self.opt.write(f)
+        if section == "client":
+            self.config_cache[option] = value
+        else:
+            self.config_cache[section][option] = value
+        # TODO: Change the database
+
     def send(self, *args):
         # TODO: Loop detection
         if len(args) > 1:
@@ -506,7 +557,7 @@ def start(base):
     # TODO: Check for broken symlinks
     common.populate(saxo_path, base)
 
-    opt = configparser.ConfigParser()
+    opt = configparser.ConfigParser(interpolation=None)
     config = os.path.join(base, "config")
     opt.read(config)
     # TODO: Defaulting?
