@@ -1,34 +1,27 @@
 # Copyright 2013, Sean B. Palmer
 # Source: http://inamidst.com/saxo/
 
-version = "0.2.001"
+version = "0.2.002"
 # WARNING: If updating anything before this message,
 # change the offset in setup.py
 
 # TODO list:
 # - Think about folding common.py into saxo.py
-# - Note the use of [plugins] in the config
-# - Document all of the available config variables
 # - Allow wildcards in [client].owner
 # - Implement [plugins].sync, copy or symlink as options
-# - Make .seen give nicely formatted dates
 # - Write documentation about basic bot operation
 # - Document the saxo, irc, self, and instruction interfaces
-# - Implement .join and .part, with persistent config writing
-# - Implement .visit and .part-analogue-with-visit
 # - Think about a packaging system
 # - Maybe write up a little guide to installing py3.3 with sqlite support
 # - Allow JSON submission to the socket IPC interface
-# - Survey commands to see if splitting or joining args is most common
 # - Write docstrings for all the public interfaces
-# - Return False to suppress error message from saxo.pipe?
 # - Allow multiple, possibly configurable, lines of output from commands?
-# - Track and mention the exit codes of command processes
-# - Handle events with commands set to "*"
 # - Plugins for pre_exec?
 # - Mode for accessing commands? ./saxo command example
 # - Make it possible to set periodic commands
 # - Make sure the test server exits correctly
+# - Dump a copy of the initialised config to the database
+# - Document the database tables
 
 path = None
 
@@ -172,7 +165,7 @@ def pipe(function):
 
     if result is not None:
         if not isinstance(result, str):
-            print("Error")
+            print("Error: expected str, got %s" % type(result))
             return
         result = result.encode("utf-8", "replace")
         sys.stdout.buffer.write(result + b"\n")
